<?php
/*
Plugin Name: BP Group Invite Email
Description: This BuddyPress component allows a group moderator to invite people via email
Version: 1.0
Revision Date: March 11, 2010
Requires at least: WPMU 2.8, BuddyPress 1.1
Tested up to: WPMU 2.9.1, BuddyPress 1.2
License: Example: GNU General Public License 2.0 (GPL) http://www.gnu.org/licenses/gpl.html
Author: Peter Anselmo, Studio66
Author URI: http://www.studio66design.com
Site Wide Only: true
*/

define ( 'BP_GIE_IS_INSTALLED', 1 );
define ( 'BP_GIE_VERSION', '1.0' );

if ( file_exists( WP_PLUGIN_DIR . '/buddypress-group-invite-email/languages/' . get_locale() . '.mo' ) )
	load_textdomain( 'bp-group-invite-email', WP_PLUGIN_DIR . '/buddypress-group-invite-email/languages/' . get_locale() . '.mo' );

require_once 'include/classes.php';

/**********************************************************************
******************SETUP AND INSTALLATION*******************************
**********************************************************************/

/**
 * bp_group_invite_email_install()
 *
 * Installs and/or upgrades the database tables
 */
function bp_group_invite_email_install() {
	global $wpdb, $bp;
	
	if ( !empty($wpdb->charset) )
		$charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
	
	$sql = "CREATE TABLE {$bp->group_invite_email->table_name} (
		  		id bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
		  		recipient_email varchar(255) NOT NULL,
		  		sender_id bigint(20) NOT NULL,
		  		group_id bigint(20) NOT NULL,
			    KEY recipeient_email (recipient_email),
			    KEY group_id (group_id),
				KEY sender_id (sender_id)
		 	   ) {$charset_collate};";

	require_once( ABSPATH . 'wp-admin/upgrade-functions.php' );
	dbDelta($sql);
	
	do_action('bp_group_invite_email_install');
}
register_activation_hook(__FILE__, 'bp_group_invite_email_install');


/**
 * bp_group_invite_email_setup_globals()
 *
 * Sets up global variables for group documents
 */
function bp_group_invite_email_setup_globals() {
	global $bp, $wpdb;

	/* For internal identification */
	$bp->group_invite_email->id = 'group_invite_email';
	$bp->group_invite_email->table_name = $wpdb->base_prefix . 'bp_group_invite_email';
	$bp->group_invite_email->format_notification_function = 'bp_group_invite_email_format_notifications';
	
	do_action('bp_group_invite_email_globals_loaded');
}
add_action( 'plugins_loaded', 'bp_group_invite_email_setup_globals', 5 );	
add_action( 'admin_menu', 'bp_group_invite_email_setup_globals', 2 );


/*
 * bp_gie_display_email_field()
 * 
 * adds a text box form field to the group "send invites" page
 */
function bp_gie_display_email_field () { ?>
	<h4><?php _e('Send an invite by Email','bp-group-invite-email'); ?></h4>
	<input type="text" name="bp_gie_recipient_email" value="" />
<?php }
add_action('bp_after_group_send_invites_list','bp_gie_display_email_field');


/*
 * bp_gie_process_invite()
 *
 * sends the actual invite email to the user, and records
 * the email and group info in the database
 */
function bp_gie_process_invite() {
	global $bp;

	$invite = new BP_Group_Invite_Email();
	$invite->recipient_email = apply_filters('bp_gie_recipient_email_data',$_POST['bp_gie_recipient_email']);
	$invite->group_id = $bp->groups->current_group->id ;
	$invite->sender_id = $bp->loggedin_user->id;
	$invite->send_email();
	$invite->save();

	do_action('bp_gie_process_invite');
}
add_action('groups_send_invites','bp_gie_process_invite');


/*
 * bp_gie_add_user_to_group()
 * 
 * adds user to invited group upon profile activation
 * bypasses usual "group invite" process on website
 */
function bp_gie_add_user_to_group($user_id) {
	
	$fields = get_userdata($user_id);

	if( $group_ids = BP_Group_Invite_Email::user_has_invites($fields->user_email)){
		foreach( $group_ids as $group_id ) {
			groups_join_group($group_id,$user_id);
			BP_Group_Invite_Email::delete_by_email_group($fields->user_email, $group_id);
		}
	}
}
add_action('user_register','bp_gie_add_user_to_group');
